/* Machine-specific elf macros for ARM.  */

#define ELFCLASSM	ELFCLASS32
#ifdef __ARMEB__
#define ELFDATAM	ELFDATA2MSB
#else
#define ELFDATAM	ELFDATA2LSB
#endif

#define MATCH_MACHINE(x)  (x == EM_ARM)

#define SHT_RELM	SHT_REL
#define Elf32_RelM	Elf32_Rel
